@@ -3,20 +3,20 @@
 #
 
 
-from ...core.adapter import named
+from ...core.adapter import call
 from ..resource.locate import LocatePackage, LocateRemote
 
 
 class LocateShell(LocatePackage):
 
-    named('/shell/')
+    call('/shell/')
     package = __name__
     directory = 'static'
 
 
 class LocateJQuery(LocateRemote):
 
-    named('/shell/external/jquery/')
+    call('/shell/external/jquery/')
     url = 'http://code.jquery.com/jquery-1.6.4.min.js'
     md5 = '9118381924c51c89d9414a311ec9c97f'
     cache = 'jquery-1.6.4'
@@ -24,9 +24,9 @@ class LocateJQuery(LocateRemote):
 
 class LocateCodeMirror(LocateRemote):
 
-    named('/shell/external/codemirror/')
-    url = 'https://nodeload.github.com/marijnh/CodeMirror2/zipball/v2.13'
-    md5 = 'ba0a4838ecb469ed40dfc43ce042fe67'
+    call('/shell/external/codemirror/')
+    url = 'https://nodeload.github.com/marijnh/CodeMirror/zipball/v2.13'
+    md5 = 'b2a4f989ba45f1778b183603f78cf883'
     cache = 'codemirror-2.13'
     is_zip = True
 
